@@ -1,4 +1,3 @@
-from __future__ import division, print_function, absolute_import
 
 import warnings
 
@@ -7,14 +6,13 @@ from numpy.testing import (assert_equal, assert_raises,
                            assert_allclose)
 import numpy.testing as npt
 
-from statsmodels.compat.scipy import factorial, factorial2
-from scipy.special import gamma
+from scipy.special import gamma, factorial, factorial2
 import scipy.stats as stats
 
 from statsmodels.distributions.edgeworth import (_faa_di_bruno_partitions,
         cumulant_from_moments, ExpandedNormal)
 
-class TestFaaDiBruno(object):
+class TestFaaDiBruno:
     def test_neg_arg(self):
         assert_raises(ValueError, _faa_di_bruno_partitions, -1)
         assert_raises(ValueError, _faa_di_bruno_partitions, 0)
@@ -46,7 +44,7 @@ def _chi2_cumulant(n, df):
     return 2**(n-1) * factorial(n - 1) * df
 
 
-class TestCumulants(object):
+class TestCumulants:
     def test_badvalues(self):
         assert_raises(ValueError, cumulant_from_moments, [1, 2, 3], 0)
         assert_raises(ValueError, cumulant_from_moments, [1, 2, 3], 4)
@@ -68,7 +66,7 @@ class TestCumulants(object):
             assert_allclose(kappa, _chi2_cumulant(n, df))
 
 
-class TestExpandedNormal(object):
+class TestExpandedNormal:
     def test_too_few_cumulants(self):
         assert_raises(ValueError, ExpandedNormal, [1])
 
